# -*- coding: utf-8 -*-

__author__ = 'Yoni Pacheco'
__email__ = 'aniversarioperu1@gmail.com'
__version__ = '0.0.2'

from twitterbot.bot import TwitterBot

__all__ = ['TwitterBot']
